@@ -22,7 +22,7 @@ use overload
     'cmp'	=> '_compare_overload',
     ;
 
-our $VERSION = '0.905';
+our $VERSION = '0.906';
 
 {
 
@@ -471,8 +471,9 @@ L<DateTime::Duration|DateTime::Duration>
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://github.com/trwyant/perl-DateTime-Fiction-JRRTolkien-Shire/issues>,
-or in electronic mail to the author.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=DateTime-Fiction-JRRTolkien-Shire>,
+L<https://github.com/trwyant/perl-DateTime-Fiction-JRRTolkien-Shire/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
